==> com.liferay.configuration.admin.web-2.0.28-sources.jar: com/liferay/configuration/admin/web/internal/constants/ConfigurationAdminWebKeys.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.configuration.admin.web.internal.constants;

/**
 * @author Brian Wing Shun Chan
 */
public class ConfigurationAdminWebKeys {

	public static final String CONFIGURATION_CATEGORY_MENU_DISPLAY =
		"CONFIGURATION_CATEGORY_MENU_DISPLAY";

	public static final String CONFIGURATION_CATEGORY_SECTION_DISPLAYS =
		"CONFIGURATION_CATEGORY_SECTION_DISPLAYS";

	public static final String CONFIGURATION_ENTRY = "CONFIGURATION_ENTRY";

	public static final String CONFIGURATION_ENTRY_RETRIEVER =
		"CONFIGURATION_ENTRY_RETRIEVER";

	public static final String CONFIGURATION_FORM_RENDERER =
		"CONFIGURATION_FORM_RENDERER";

	public static final String CONFIGURATION_MODEL = "CONFIGURATION_MODEL";

	public static final String CONFIGURATION_MODEL_FORM_HTML =
		"CONFIGURATION_MODEL_FORM_HTML";

	public static final String CONFIGURATION_MODEL_ITERATOR =
		"CONFIGURATION_MODEL_ITERATOR";

	public static final String CONFIGURATION_SCREEN = "CONFIGURATION_SCREEN";

	public static final String FACTORY_CONFIGURATION_MODEL =
		"FACTORY_CONFIGURATION_MODEL";

	public static final String RESOURCE_BUNDLE_LOADER_PROVIDER =
		"RESOURCE_BUNDLE_LOADER_PROVIDER";

}

==> com.liferay.configuration.admin.web-3.0.90-sources.jar: com/liferay/configuration/admin/web/internal/constants/ConfigurationAdminWebKeys.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.configuration.admin.web.internal.constants;

/**
 * @author Brian Wing Shun Chan
 */
public class ConfigurationAdminWebKeys {

	public static final String CONFIGURATION_CATEGORY_MENU_DISPLAY =
		"CONFIGURATION_CATEGORY_MENU_DISPLAY";

	public static final String CONFIGURATION_CATEGORY_SECTION_DISPLAYS =
		"CONFIGURATION_CATEGORY_SECTION_DISPLAYS";

	public static final String CONFIGURATION_ENTRY = "CONFIGURATION_ENTRY";

	public static final String CONFIGURATION_ENTRY_ITERATOR =
		"CONFIGURATION_ENTRY_ITERATOR";

	public static final String CONFIGURATION_ENTRY_RETRIEVER =
		"CONFIGURATION_ENTRY_RETRIEVER";

	public static final String CONFIGURATION_FORM_RENDERER =
		"CONFIGURATION_FORM_RENDERER";

	public static final String CONFIGURATION_MENU_ITEMS =
		"CONFIGURATION_MENU_ITEMS";

	public static final String CONFIGURATION_MODEL = "CONFIGURATION_MODEL";

	public static final String CONFIGURATION_MODEL_FORM_HTML =
		"CONFIGURATION_MODEL_FORM_HTML";

	public static final String CONFIGURATION_MODEL_ITERATOR =
		"CONFIGURATION_MODEL_ITERATOR";

	public static final String CONFIGURATION_SCREEN = "CONFIGURATION_SCREEN";

	public static final String FACTORY_CONFIGURATION_MODEL =
		"FACTORY_CONFIGURATION_MODEL";

	public static final String RESOURCE_BUNDLE_LOADER_PROVIDER =
		"RESOURCE_BUNDLE_LOADER_PROVIDER";

}
